==> marklogic-xcc-11.3.0-sources.jar: com/marklogic/xcc/impl/handlers/ServiceUnavailableHandler.java <==
/*
 * Copyright (c) 2023 MarkLogic Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.marklogic.xcc.impl.handlers;

import java.io.IOException;
import java.util.logging.Logger;

import com.marklogic.http.HttpChannel;
import com.marklogic.xcc.Request;
import com.marklogic.xcc.exceptions.MLCloudRequestException;
import com.marklogic.xcc.exceptions.RequestException;
import com.marklogic.xcc.exceptions.ServerConnectionException;

public class ServiceUnavailableHandler implements ResponseHandler {
    public Object handleResponse(HttpChannel http, int responseCode, Request request, Object attachment, Logger logger)
            throws RequestException {
        String responseMessage = null;

        try {
            responseMessage = http.getResponseMessage();
        } catch (IOException e) {
            responseMessage = "(no message returned by server)";
        }
        if (request.getSession().getUserCredentials().getMLCloudAuthConfig()
            != null) {
            // Response from MarkLogic Cloud, retryable exception
            throw new MLCloudRequestException("(" + responseCode + ", " +
                responseMessage + "). MarkLogic Cloud cannot accept request.",
                request, true);
        }
        throw new ServerConnectionException("Server cannot accept request: " + responseMessage, request);
    }
}

==> marklogic-xcc-12.0.0-sources.jar: com/marklogic/xcc/impl/handlers/ServiceUnavailableHandler.java <==
/*
 * Copyright (c) 2006-2025 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.marklogic.xcc.impl.handlers;

import java.io.IOException;
import java.util.logging.Logger;

import com.marklogic.http.HttpChannel;
import com.marklogic.xcc.Request;
import com.marklogic.xcc.exceptions.PDCloudRequestException;
import com.marklogic.xcc.exceptions.RequestException;
import com.marklogic.xcc.exceptions.ServerConnectionException;

public class ServiceUnavailableHandler implements ResponseHandler {
    public Object handleResponse(HttpChannel http, int responseCode, Request request, Object attachment, Logger logger)
            throws RequestException {
        String responseMessage = null;

        try {
            responseMessage = http.getResponseMessage();
        } catch (IOException e) {
            responseMessage = "(no message returned by server)";
        }
        if (request.getSession().getUserCredentials().getPDCloudAuthConfig()
            != null) {
            // Response from MarkLogic Cloud, retryable exception
            throw new PDCloudRequestException("(" + responseCode + ", " +
                responseMessage + "). Progress Data Cloud cannot accept request.",
                request, true);
        }
        throw new ServerConnectionException("Server cannot accept request: " + responseMessage, request);
    }
}
